@@ -64,7 +64,7 @@ use namespace::autoclean;
 
 # PODNAME: Dist::Zilla::Plugin::Manifest::Write
 # ABSTRACT: Have annotated distribution manifest
-our $VERSION = 'v0.9.2'; # VERSION
+our $VERSION = 'v0.9.3'; # VERSION
 
 with 'Dist::Zilla::Role::FileGatherer';
 with 'Dist::Zilla::Role::BeforeBuild';
@@ -717,7 +717,7 @@ sub _file_adder {
                 ] );
         } else {
             $self->log_error( [
-                "can't find file %s adder: %s is not a plugins", $file->name, $name
+                "can't find file %s adder: %s is not a plugin", $file->name, $name
             ] );
         };
     } else {
@@ -865,7 +865,7 @@ Dist::Zilla::Plugin::Manifest::Write - Have annotated distribution manifest
 
 =head1 VERSION
 
-Version v0.9.2, released on 2015-10-04 21:21 UTC.
+Version v0.9.3, released on 2015-10-07 08:03 UTC.
 
 =head1 WHAT?
 
@@ -1137,23 +1137,6 @@ A module shown in Synopsis is a real example. Its result looks like:
     dist.ini     #     Dummy file added by GatherDir (207 bytes)
     lib/Dummy.pm #     Dummy file added by GatherDir (22 bytes)
 
-=head1 COPYRIGHT AND LICENSE
-
-Copyright © 2015 Van de Bugger
-
-This file is part of perl-Dist-Zilla-Plugin-Manifest-Write.
-
-perl-Dist-Zilla-Plugin-Manifest-Write is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by the Free Software
-Foundation, either version 3 of the License, or (at your option) any later version.
-
-perl-Dist-Zilla-Plugin-Manifest-Write is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-perl-Dist-Zilla-Plugin-Manifest-Write. If not, see <http://www.gnu.org/licenses/>.
-
 =head1 SEE ALSO
 
 =over 4
@@ -1180,12 +1163,19 @@ Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 Van de Bugger
+Copyright © 2015 Van de Bugger
 
-License GPLv3+: The GNU General Public License version 3 or later
-<http://www.gnu.org/licenses/gpl-3.0.txt>.
+This file is part of perl-Dist-Zilla-Plugin-Manifest-Write.
 
-This is free software: you are free to change and redistribute it. There is
-NO WARRANTY, to the extent permitted by law.
+perl-Dist-Zilla-Plugin-Manifest-Write is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by the Free Software
+Foundation, either version 3 of the License, or (at your option) any later version.
+
+perl-Dist-Zilla-Plugin-Manifest-Write is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+PARTICULAR PURPOSE. See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with
+perl-Dist-Zilla-Plugin-Manifest-Write. If not, see <http://www.gnu.org/licenses/>.
 
 =cut
